==> commons-utils-2.4.0-sources.jar: org/seppiko/commons/utils/http/HttpResponseException.java <==
/*
 * Copyright 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils.http;

import java.io.Serial;

/**
 * Http Response Exception
 * A subclass of HttpClientException
 *
 * @author Leonard Woo
 */
public class HttpResponseException extends HttpClientException {

  @Serial
  private static final long serialVersionUID = -7791583373994207906L;

  /**
   * Default Exception
   */
  public HttpResponseException() {
  }

  /**
   * Exception with message
   *
   * @param message message
   */
  public HttpResponseException(String message) {
    super(message);
  }

  /**
   * Exception with message and Throwable
   *
   * @param message message
   * @param cause other exception
   */
  public HttpResponseException(String message, Throwable cause) {
    super(message, cause);
  }

  /**
   * Exception with Throwable
   *
   * @param cause other exception
   */
  public HttpResponseException(Throwable cause) {
    super(cause);
  }
}

==> commons-utils-2.9.0-sources.jar: org/seppiko/commons/utils/http/HttpResponseException.java <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils.http;

import java.io.Serial;

/**
 * Http Response Exception A subclass of HttpClientException
 *
 * @author Leonard Woo
 */
public class HttpResponseException extends HttpClientException {

  @Serial private static final long serialVersionUID = -7791583373994207906L;

  /** Default Exception */
  public HttpResponseException() {
    super();
  }

  /**
   * Exception with message
   *
   * @param message message
   */
  public HttpResponseException(String message) {
    super(message);
  }

  /**
   * Exception with message and Throwable
   *
   * @param message message
   * @param cause other exception
   */
  public HttpResponseException(String message, Throwable cause) {
    super(message, cause);
  }

  /**
   * Exception with Throwable
   *
   * @param cause other exception
   */
  public HttpResponseException(Throwable cause) {
    super(cause);
  }
}
